Struct AccountData Copy item path Source #[non_exhaustive]
pub struct AccountData {
pub enabled: Option <bool >,
pub lists: Option <Vec <String >>,
pub rooms: Option <Vec <ExtensionRoomConfig >>,
}Available on crate feature unstable-msc4186 and (crate features client or server) only.
Expand description This struct is marked as non-exhaustive Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
Activate or deactivate this extension.
List of list names for which account data should be enabled.
This is specific to room account data (e.g. user-defined room tags).
If not defined, will be enabled for all the lists appearing in the
request. If defined and empty, will be disabled for all the lists.
List of room names for which account data should be enabled.
This is specific to room account data (e.g. user-defined room tags).
If not defined, will be enabled for all the rooms appearing in the
room subscriptions. If defined and empty, will be disabled for all
the rooms.
Whether all fields are empty or None.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Returns the “default value” for a type.
Read more Deserialize this value from the given Serde deserializer.
Read more Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more The DropFlavor that
wraps
T into
SelfReturns the argument unchanged.
Create a new handle for an Arc value
Read more Consume a handle, getting back the initial
Arc<> Read more Get a clone of the
Arc<> using a “borrowed” handle.
Read more A constant of the type witness
Proof that Self is the same type as Self::Type,
provides methods for casting between Self and Self::Type.
The same type as Self,
used to emulate type equality bounds (T == U)
with associated type equality constraints
(T: Identity<Type = U>).
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.