#[non_exhaustive]pub struct Profiles {
pub enabled: Option<bool>,
pub lists: Option<Vec<String>>,
pub rooms: Option<Vec<ExtensionRoomConfig>>,
pub fields: Option<Vec<ProfileFieldName>>,
}Available on crate feature
unstable-msc4186 and crate feature unstable-msc4262 and (crate features client or server) only.Expand description
User profiles extension.
Specified as part of MSC4262.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: Option<bool>Activate or deactivate this extension.
lists: Option<Vec<String>>List of list names for which user profiles should be enabled.
If not defined, will be enabled for all the lists appearing in the request. If defined and empty, will be disabled for all the lists.
rooms: Option<Vec<ExtensionRoomConfig>>List of room names for which user profiles should be enabled.
If not defined, will be enabled for all the rooms appearing in the room subscriptions. If defined and empty, will be disabled for all the rooms.
fields: Option<Vec<ProfileFieldName>>Optional filter to control which profile fields to receive updates for. If omitted, all profile field updates are included.
Implementations