#[non_exhaustive]pub struct ListFilters {
pub is_dm: Option<bool>,
pub is_encrypted: Option<bool>,
pub is_invite: Option<bool>,
pub room_types: Vec<RoomTypeFilter>,
pub not_room_types: Vec<RoomTypeFilter>,
}client or server) and crate feature unstable-msc4186 only.Expand description
A sliding sync list request filters (see List::filters).
All fields are applied with AND operators. The absence of fields
implies no filter on that criteria: it does NOT imply false.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_dm: Option<bool>Whether to return only DM rooms (as determined by the m.direct account data event),
only non-DM rooms, or both.
is_encrypted: Option<bool>Whether to return only encrypted rooms (as determined by the existence of an
m.room.encryption state event), only unencrypted rooms, or both.
is_invite: Option<bool>Whether to return only invited rooms, only joined rooms, or both.
room_types: Vec<RoomTypeFilter>Only list rooms with these create-types, or all.
If a room type is specified in both room_types and not_room_types,
not_room_types wins and the corresponding rooms are not included.
not_room_types: Vec<RoomTypeFilter>Only list rooms that are not of these create-types, or all.
If a room type is specified in both room_types and not_room_types,
not_room_types wins and the corresponding rooms are not included.